var fs = require('fs'),
    path = require('path'),
    lcp = require('line-comment-parser'),
    touch = require('touch');

module.exports = {
  openFileSync: function(filepath){
    return fs.readFileSync(filepath, 'utf-8');
  },
  getComments: function(filepath){
    var input = this.openFileSync(filepath);
    return lcp.getComments(input);
  },
  getImportedFileNames: function(filepath){
    var mainFile = this.openFileSync(filepath);
    var split = mainFile.split(/@import/);
    var files = [];
    for(var i in split){
      var subStr = split[i];
      if(subStr.includes(';')){
        files.push(subStr.replace(/("|'|;)/gi, '').trim());
      }
    }
    return files;
  },
  getExtension: function(filepath){
    if(fs.existsSync(filepath + '.scss')){
      return filepath+'.scss';
    }
    if(fs.existsSync(filepath + '.css')){
      return filepath+'.css';
    }
    return false;
  },
  getAllComments: function(rootFile){
    var fileNames = this.getImportedFileNames(rootFile);
    var dir = path.dirname(rootFile) + '/';
    var comments = [];
    for(var i in fileNames){
      var fileName = fileNames[i];
      var filePath = this.getExtension(dir + fileName);
      if(filePath){
          comments.push({
            'fileName': fileName,
            'comments': this.getComments(filePath)
          });
          // comments[fileName] = this.getComments(filePath);
      }
    }
    return comments;
  },
  formattedContent: function(fileComments){
    return fileComments.fileName + ':\n\t' + fileComments.comments.reduce(function(concat, obj){
        // var initialLength = obj.length;
        obj = obj.replace(/=/gi, '');
        if(obj.length>0){
          return concat + ', ' + obj;
        }
        return concat;
    })
    +'\n';
  },
  generateReadme: function(rootFile){
    var comments = this.getAllComments(rootFile);
    var writeString = "";
    var module = this;
    writeString =
    comments.reduce(function(concat, obj){
        return concat + module.formattedContent(obj);
      },
      module.formattedContent(comments[0]));
    // console.log(writeString);
    return writeString;
  },
  writeReadme: function(rootfile, writeFile){
    var writeString = this.generateReadme(rootfile);
    // console.log(writeFile)
    touch.sync(writeFile);
    fs.writeFile(writeFile, writeString);
  }
}
